package #
    TestApp;
use base 'Catalyst';

__PACKAGE__->setup;

1;
